@@ -46,6 +46,7 @@ class Crawler():
             self.before             = beforeSrc
             self.after              = afterSrc
             self.matchSize          = matchSizeSrc
+            self.beginnRootRelPath  = 0
 
             self._printCrawlerMessage('[+] Init Crawler')
             LOG.debug("Init Crawler")
@@ -59,8 +60,12 @@ class Crawler():
                 self.rootFilePath = pathSrc
 
             # set relative path
-            if self.rootFilePath != pathSrc:
+            if self.rootFilePath != pathSrc and pathSrc != '.':
                 self.rootRelPath = os.path.relpath(pathSrc)
+                self.beginnRootRelPath = len(self.rootFilePath) - len(self.rootRelPath)
+            elif pathSrc == '.':
+                self.rootRelPath = self.rootFilePath[self.rootFilePath.rfind('/') + 1:]
+                self.beginnRootRelPath = len(self.rootFilePath)
             else:
                 self.rootRelPath = pathSrc
 
@@ -198,7 +203,10 @@ class Crawler():
 
         for item in self.resultList:
             for ioc in item.mCount:
-                summaryDict[ioc] = item.mCount[ioc]
+                if ioc in summaryDict.keys():
+                    summaryDict[ioc] = summaryDict[ioc] + item.mCount[ioc]
+                else:
+                    summaryDict[ioc] = item.mCount[ioc]
 
         return summaryDict
     # end def getResultSummary
@@ -212,7 +220,7 @@ class Crawler():
             for file in blockFiles:
                 try:
                     # create value object for the results - save only the relative path to the results
-                    cvo = CrawlerVo(file[len(self.rootRelPath):])
+                    cvo = CrawlerVo(file[self.beginnRootRelPath:])
 
                     with open(file, 'rb') as f:
                         LOG.debug("Processing %s" %(file))
@@ -225,7 +233,7 @@ class Crawler():
                         if fileSize < bufSize:
                             bufSize = fileSize
                             overlap = 0
-                        dbgCOUNTER = 0
+                        
                         # read the file in blocks
                         while filePos < fileSize:
 
@@ -263,16 +271,18 @@ class Crawler():
                                                     raise CrawlerError("self.after not implemented")
                                                     #after = buffer[item.start() + len(matchString): item.start() + len(matchString) + self.after].decode("utf-8")
                                                 
+                                                # maybe feature in one of the next versions
                                                 #printDict = {"file" : file, "ioc" : ioc_type, 
                                                 #            "match": before + matchString + after, "offset": str(filePos + item.start())}
 
                                                 # hint: save only relative path
-                                                printDict = {"file" : file[len(self.rootRelPath):], "ioc" : ioc_type, "match": matchString, "offset": str(filePos + item.start())}
+                                                printDict = {"path" : file[self.beginnRootRelPath:], "ioc" : ioc_type, "match": matchString, "offset": str(filePos + item.start())}
 
                                                 isWhiteListed = False
 
                                                 if self.whitlist:
                                                     if matchString in self.whitlist:
+
                                                         isWhiteListed = True
                                                         with self.processedFileCount.get_lock():
                                                             self.whiteListedMatches.value +=1
